@@ -1,4 +1,4 @@
-# $Id: install.py 846 2014-02-02 22:03:11Z mwall $
+# $Id: install.py 978 2014-08-09 02:37:11Z mwall $
 # installer for OWFS
 # Copyright 2014 Matthew Wall
 
@@ -10,7 +10,7 @@ def loader():
 class OWFSInstaller(ExtensionInstaller):
     def __init__(self):
         super(OWFSInstaller, self).__init__(
-            version="0.2",
+            version="0.6",
             name='owfs',
             description='driver for one-wire devices connected via owfs',
             author="Matthew Wall",
@@ -22,6 +22,6 @@ class OWFSInstaller(ExtensionInstaller):
                     'interface': 'u',
                     'driver': 'user.owfs',
                     'sensor_map': {},
-                    'data_type': {}}},
+                    'sensor_type': {}}},
             files=[('bin/user', ['bin/user/owfs.py'])]
             )
